# Shodo Python CLI

The Shodo Python CLI help you, lint Japanese text and download posts and images.

## Installation

```bash
$ pip install shodo
```

## Usage

Installing the CLI provides access to the `shodo` command.

```bash
$ shodo [COMMAND]

# Run `--help` for more information about CLI commands
$ shodo [COMMAND] --help
```

## Commands

The Shodo Python CLI provides the following commands:

* [`login`](https://developer.shodo.ink/docs/shodo-cli-reference#shodo-login)
* [`lint`](https://developer.shodo.ink/docs/shodo-cli-reference#shodo-lint)
* [`download`](https://developer.shodo.ink/docs/shodo-cli-reference#shodo-download)

## Documentation

For additional information, please refer to the [Shodo Python CLI documentation](https://developer.shodo.ink/docs/shodo-cli-reference).
